# dictdaora

<p align="center" style="margin: 3em">
  <a href="">
    <img src="python.svg" alt="dictdaora" width="300"/>
  </a>
</p>

<p align="center">
    <em>Dicts that can be accessed via attributes</em>
</p>

---

**Documentation**: <a href="#" target="_blank"></a>

**Source Code**: <a href="#" target="_blank"></a>

---


## Key Features

- Print hello world on screen *

*\* feature in development.*


## Requirements

 - Python 3.8+


## Instalation
```
$ pip install dictdaora
```


## Basic example

```python
{!./src/index/index_00_basic.py!}
```

```
{!./src/index/index_00_basic.output!}
```


## Complex example

```python
{!./src/index/index_02_complex.py!}
```

```
{!./src/index/index_02_complex.output!}
```
